@@ -33,11 +33,11 @@ public:
         { }
 
 protected:
-    virtual void _make_prefix();
+    virtual void _make_prefix(time_t now);
 };
 
 
-void WvDialLogger::_make_prefix()
+void WvDialLogger::_make_prefix(time_t now)
 /*******************************/
 {
     WvString name = last_source;
@@ -118,7 +118,6 @@ int main(int argc, char **argv)
 			 "Also, optional OPTION=value parameters allow you "
 			 "to override options within\n"
 			 "the configuration files.\n");
-    args.set_email("<wvdial-list@lists.nit.ca>");
 
     args.add_option('C', "config",
 		    "use configfile instead of /etc/wvdial.conf",
